# Time Stamper

Under construction! Not ready for use yet! Currently testing and planning!

Developed by Sandun Sampath Vitharana from Sri Lanka (c) 2024

## Examples of How To Use (Buggy Alpha Version)

Creating A Server

```python
from datetime date time
print(datetime.now())
```

Creating A Client
```python
print("Hey")
```

Check out: https://www.youtube.com/@vitharana1996